// Copyright 2000 Omni Development, Inc.  All rights reserved.
//
// This software may only be used and reproduced according to the
// terms in the file OmniSourceLicense.html, which should be
// distributed with this project and can also be found at
// http://www.omnigroup.com/DeveloperResources/OmniSourceLicense.html.

#import "OHVDocument.h"

#import <Foundation/Foundation.h>
#import <AppKit/AppKit.h>
#import <OmniBase/OmniBase.h>
#import <OmniFoundation/OmniFoundation.h>
#import <OmniAppKit/OmniAppKit.h>
#import <OWF/OWF.h>
#import <OmniHTML/OmniHTML.h>

#import "OHVDocumentFrameView.h"

RCS_ID("$Header: /Network/Source/CVS/OmniGroup/Applications/OmniHTMLViewer/OHVDocument.m,v 1.1 2000/05/28 22:08:48 kc Exp $")

@interface OHVDocument (Private)
// API
- (BOOL)readFromAddress:(OWAddress *)address;
@end

@implementation OHVDocument

NSString *OHVDocumentTaskHeaderName = @"Documents";

// NSDocument subclass

- (NSString *)windowNibName;
{
    // Override returning the nib file name of the document
    return @"OHVDocument";
}

- (void)windowControllerDidLoadNib:(NSWindowController *)aController;
{
    [super windowControllerDidLoadNib:aController];
    // Add any code here that need to be executed once the windowController has loaded the document's window.
    if (document)
        [documentFrameView setDocumentView:[document omniDocumentView]];
}

- (NSData *)dataRepresentationOfType:(NSString *)aType;
{
    // Insert code here to write your document from the given data.  You can also choose to override -fileWrapperRepresentationOfType: or -writeToFile:ofType: instead.
    return nil;
}

- (BOOL)readFromFile:(NSString *)fileName ofType:(NSString *)type;
{
    return [self readFromAddress:[OWAddress addressWithFilename:fileName]];
}

- (BOOL)readFromURL:(NSURL *)url ofType:(NSString *)type;
{
    return [self readFromAddress:[OWAddress addressForDirtyString:[url absoluteString]]];
}


// Init and dealloc

- (void)dealloc;
{
    [OWPipeline cancelTarget:self];
    [document release];

    [super dealloc];
}


// Actions

- (IBAction)reload:(id)sender;
{
    OWPipeline *pipeline;

    pipeline = [OWPipeline currentPipelineForTarget:self];
    [pipeline deepFlushContentCache];
    [pipeline refetchContentFromLastAddress];
}

- (IBAction)printDocument:(id)sender;
{
    [documentFrameView print:sender];
}


// OWTarget protocol

- (OWContentType *)targetContentType;
{
    return [OHDocumentView contentType];
}

- (OWTargetContentDisposition)pipeline:(OWPipeline *)aPipeline hasContent:(id <OWContent>)someContent;
{
    OBPRECONDITION(document == nil);

    document = [(id <OHDocument>)someContent retain];
    if (documentFrameView)
        [documentFrameView setDocumentView:[document omniDocumentView]];

    return OWTargetContentDisposition_ContentAccepted;
}

- (NSString *)targetTypeFormatString;
{
    return @"%@ Document"; // "HTML Document"
}

- (OWContentInfo *)parentContentInfo;
{
    return [OWContentInfo headerContentInfoWithName:OHVDocumentTaskHeaderName];
}


// OWOptionalTarget protocol

- (OWTargetContentDisposition)pipeline:(OWPipeline *)aPipeline hasAlternateContent:(id <OWContent>)someContent;
{
    NSLog(@"Cannot display content of type %@", [[someContent contentType] shortDescription]);
    return OWTargetContentDisposition_ContentRejectedCancelPipeline;
}

- (OWTargetContentDisposition)pipeline:(OWPipeline *)aPipeline hasErrorContent:(id <OWContent>)someContent;
{
    NSLog(@"Error displaying %@ (errorContent=%@)", [(OWAddress *)[aPipeline lastAddress] shortDescription], someContent);
    return OWTargetContentDisposition_ContentRejectedCancelPipeline;
}


// NSWindow delegate

- (void)windowWillClose:(NSNotification *)notification;
{
    [document release];
    document = nil;
}

@end


@implementation OHVDocument (Private)

- (BOOL)readFromAddress:(OWAddress *)address;
{
    OWPipeline *pipeline;

    pipeline = [[OWPipeline alloc] initWithContent:address target:self];
    [pipeline startProcessingContent];
    [pipeline release];

    return YES;
}

@end
