// Copyright 2000 Omni Development, Inc.  All rights reserved.
//
// This software may only be used and reproduced according to the
// terms in the file OmniSourceLicense.html, which should be
// distributed with this project and can also be found at
// http://www.omnigroup.com/DeveloperResources/OmniSourceLicense.html.

#import "OHVDocumentFrameView.h"

#import <AppKit/AppKit.h>
#import <OmniBase/OmniBase.h> // For RCS_ID()
#import <OmniAppKit/OmniAppKit.h> // For OAScrollView
#import <OmniHTML/OmniHTML.h>

RCS_ID("$Header: /Network/Source/CVS/OmniGroup/Applications/OmniHTMLViewer/OHVDocumentFrameView.m,v 1.1 2000/05/28 22:08:48 kc Exp $")

@implementation OHVDocumentFrameView

- initWithFrame:(NSRect)aFrame;
{
    if (![super initWithFrame:aFrame])
        return nil;

    [self setAutoresizesSubviews:YES];
    scrollView = [[OAScrollView alloc] initWithFrame:[self bounds]];
    [scrollView setAutoresizesSubviews:YES];
    [scrollView setAutoresizingMask:NSViewWidthSizable | NSViewHeightSizable];
    [self addSubview:scrollView];

    return self;
}

- (void)dealloc;
{
    // Nullify our document view's backpointer (in case it's still retained by someone else and gets accessed after we're gone).
    [documentView setFrameView:nil];
    [documentView release];
    [scrollView release];

    [super dealloc];
}

// API

- (void)setDocumentView:(NSView <OHDocumentView> *)newDocumentView;
{
    BOOL documentViewResizesAutomatically;

    OBPRECONDITION(documentView == nil);

    documentView = [newDocumentView retain];
    [documentView setAutoresizingMask:NSViewWidthSizable | NSViewHeightSizable];
    [documentView setFrameView:self];

    // Put the new documentView into the scrollView, and either let it know it needs to be resized (if it implements -documentDisplayedInNewFrame) or set its size directly (if not).
    documentViewResizesAutomatically = [documentView respondsToSelector:@selector(documentDisplayedInNewFrame)];

    if (!documentViewResizesAutomatically)
        [documentView setFrameSize:[scrollView contentSize]];
    
    [scrollView setDocumentView:documentView];

    if (documentViewResizesAutomatically)
        [(id <OHOptionalDocumentView>)documentView documentDisplayedInNewFrame];
}

// OHDocumentFrame protocol

// Selecting and following links

- (void)documentViewSelectionDidChange;
    // Documents call this method when their selectedLink changes.
{
}

- (void)displayDocumentAtAddress:(OWAddress *)anAddress;
    // Display the document at the specified address.  Documents ask the frame to display a new address when a hypertext link is followed.
{
}

// Active frame

- (void)becomeActiveFrame;
    // When a document view becomes the first responder, it lets its frame know that it is now the active frame.
{
}

- (void)resignActiveFrame;
    // When a document view resigns from being first responder, it lets its frame know that it is no longer the active frame.
{
}

// Utility methods

- (void)drawFrameBorderForDocumentView:(NSView *)aDocumentView rect:(NSRect)aRect;
    // A document view will call this in its -drawRect: to draw the frame's highlight border over itself.
{
}

- (void)documentViewKeyDown:(NSEvent *)keyDownEvent;
    // This handles common keystrokes like arrow keys, page up, page down, etc.
{
}

// Scripting

- (OWScriptFrameProxy *)scriptProxy;
{
    // JavaScript isn't going to work in this trivial app, I'm afraid.
    return nil;
}

@end
